<%#
# Copyright 2016 Google Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
%>
<html>
  <head>
    <script src="https://apis.google.com/js/platform.js" async defer></script>
    <meta name="google-signin-client_id" content="<%= @client_id %>">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <style type="text/css">
      .navigation a {
        padding: 10px;
      }
      .main {
        padding: 10px;
      }
    </style>
  </head>
  <body>
    <div class="navigation">
      <a href="/">Home</a>
      <a href="/drive">Google Drive Sample</a>
      <a href="/calendar">Google Calendar Sample</a>
    </div>
    <div class="main">
      <%= yield %>
    </div>
  </body>
</html>
