<%#
# Copyright 2016 Google Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
%>
<section>
  <h5>Next 10 events</h5>
  <table class="">
    <thead>
    <tr>
      <th class="">Time</th>
      <th class="">Summary</th>
    </tr>
    </thead>
    <tbody>
    <% @result.items.each do |event| %>
        <tr>
          <td class=""><%= event.start.date_time || event.start.date %></td>
          <td class=""><%= event.summary %></td>
        </tr>
    <% end %>
    </tbody>
  </table>
</section>
