<%#
# Copyright 2016 Google Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
%>
<div class="g-signin2" data-onsuccess="onSignIn"></div>
<script>
function onSignIn(googleUser) {
  var id_token = googleUser.getAuthResponse().id_token;
  var formData = new FormData();
  formData.append('id_token', id_token);
  var req = new XMLHttpRequest();
  req.addEventListener("load", function() {
    console.log("Log in successful");
    // Successful login...
  });
  req.addEventListener("error", function() {
    console.log("Log in failed");
    // Handle error...
  });
  req.open("POST", "/signin");
  req.send(formData);
}
</script>
